RESTFUL_HEADER = {
    'Content-type': 'application/json',
    'Accept': 'application/json',
}

# Header names from request
HTTP_API_KEY = 'HTTP_API_KEY'
HTTP_USER_TOKEN = 'HTTP_USER_TOKEN'
HTTP_FROM = 'HTTP_X_FORWARDED_FOR'

# Header names from response
USER_TOKEN = 'user-token'
API_KEY = 'api-key'
CLIENT_IP = 'client-ip'

# Response content
MESSAGE = 'message'
SUCCESS = 'success'
ERROR = 'error'
RESPONSE = 'response'
EXPIRATION_DATE = 'expiration-date'
